#
# spec file for package sofia-sip
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_major 1.12
%define with_doxygen 0
Name:           sofia-sip
Version:        1.12.11+20110422
Release:        2.5
Summary:        A RFC3261 compliant SIP User-Agent library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://sofia-sip.sf.net/
Source0:        http://deb.debian.org/debian/pool/main/s/sofia-sip/sofia-sip_%{version}.1.orig.tar.gz
Patch0:         http://deb.debian.org/debian/pool/main/s/sofia-sip/sofia-sip_%{version}.1-2.1.diff.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  openssl-devel
%if 0%{?with_doxygen}
BuildRequires:  doxygen
BuildRequires:  graphviz
%endif
Provides:       %{name}-utils = %{version}-%{release}

%description
Sofia-SIP is an open-source SIP  User-Agent library, compliant with the
IETF RFC3261 specification. It can be used as a building block for SIP
client software for uses such as VoIP, IM, and many other real-time and
person-to-person communication services. The primary target platform
for Sofia-SIP is GNU/Linux. Sofia-SIP is based on a SIP stack developed
at the Nokia Research Center.

This package holds the cli tools what ship with sofia-sip.

%package devel
Summary:        Development files for sofia-sip
Group:          Development/Libraries/C and C++
Requires:       glib2-devel
Requires:       libsofia-sip-ua-glib3 = %{version}
Requires:       libsofia-sip-ua0 = %{version}
Requires:       openssl-devel

%description devel
Sofia-SIP is an open-source SIP  User-Agent library, compliant with the
IETF RFC3261 specification. It can be used as a building block for SIP
client software for uses such as VoIP, IM, and many other real-time and
person-to-person communication services. The primary target platform
for Sofia-SIP is GNU/Linux. Sofia-SIP is based on a SIP stack developed
at the Nokia Research Center.

This package holds the development files.

%package -n libsofia-sip-ua0
#
Summary:        A RFC3261 compliant SIP User-Agent library
Group:          Development/Libraries/C and C++

%description -n libsofia-sip-ua0
Sofia-SIP is an open-source SIP  User-Agent library, compliant with the
IETF RFC3261 specification. It can be used as a building block for SIP
client software for uses such as VoIP, IM, and many other real-time and
person-to-person communication services. The primary target platform
for Sofia-SIP is GNU/Linux. Sofia-SIP is based on a SIP stack developed
at the Nokia Research Center.

This package holds the shared libraries.

%package -n libsofia-sip-ua-glib3
#
Summary:        A RFC3261 compliant SIP User-Agent library  (glib2 bindings)
Group:          Development/Libraries/C and C++
Provides:       %{name}-glib = %{version}-%{release}

%description -n libsofia-sip-ua-glib3
Sofia-SIP is an open-source SIP  User-Agent library, compliant with the
IETF RFC3261 specification. It can be used as a building block for SIP
client software for uses such as VoIP, IM, and many other real-time and
person-to-person communication services. The primary target platform
for Sofia-SIP is GNU/Linux. Sofia-SIP is based on a SIP stack developed
at the Nokia Research Center.

This package holds the glib2 bindings.

%prep
%autosetup -p1 -n %{name}-%{version}.1
find . -name "*.awk" -exec sed -i 's|#! /usr/bin/env awk|#!/usr/bin/awk|g' {} \;

%build
%configure --disable-static
%make_build
%if 0%{?with_doxygen}
%make_build doxygen
%endif

%check
#%%make_build check

%install
%make_install
%if 0%{?with_doxygen}
cp -av libsofia-sip-ua/docs/html %{buildroot}%{_docdir}/%{name}/manual
%endif
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post   -n libsofia-sip-ua0      -p /sbin/ldconfig
%postun -n libsofia-sip-ua0      -p /sbin/ldconfig
%post   -n libsofia-sip-ua-glib3 -p /sbin/ldconfig
%postun -n libsofia-sip-ua-glib3 -p /sbin/ldconfig

%files -n libsofia-sip-ua0
%license COPYRIGHTS COPYING
%doc AUTHORS ChangeLog* README* RELEASE
%{_libdir}/libsofia-sip-ua.so.0*

%files
%{_bindir}/addrinfo
%{_bindir}/localinfo
%{_bindir}/sip-date
%{_bindir}/sip-dig
%{_bindir}/sip-options
%{_bindir}/stunc
%{_mandir}/man1/addrinfo.1%{?ext_man}
%{_mandir}/man1/localinfo.1%{?ext_man}
%{_mandir}/man1/sip-date.1%{?ext_man}
%{_mandir}/man1/sip-dig.1%{?ext_man}
%{_mandir}/man1/sip-options.1%{?ext_man}
%{_mandir}/man1/stunc.1%{?ext_man}

%files -n libsofia-sip-ua-glib3
%{_libdir}/libsofia-sip-ua-glib.so.3*

%files devel
%dir %{_includedir}/sofia-sip-%{pkg_major}/
%{_includedir}/sofia-sip-%{pkg_major}/sofia-sip/
%{_includedir}/sofia-sip-%{pkg_major}/sofia-resolv/
%{_libdir}/libsofia-sip-ua.so
%{_libdir}/libsofia-sip-ua-glib.so
%{_libdir}/pkgconfig/sofia-sip-ua-glib.pc
%{_libdir}/pkgconfig/sofia-sip-ua.pc
%{_datadir}/sofia-sip/
%if 0%{?with_doxygen}
%doc %{_docdir}/%{name}/manual
%endif

%changelog
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup instead of %%setup/%%patch.
* Wed Jun  3 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.12.11+20110422
  * In the 1.12.11 release, SOATAG_LOCAL_SDP_STR_REF is broken (but
    that is fixed in commmit bcd0f17f). Let's use the same version
    debian/ubuntu are using.
- Add patch (various fixes from the debian package):
  * sofia-sip_1.12.11+20110422.1-2.1.diff.gz
- Package cleanup
- Remove compat ifdefs for old SLE versions
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 1.12.11:
  + Application can feed hashed passwords (HA1) instead of plain
    text password to the iptsec authentication library.
  + Using NTATAG_EXTRA_100() with server transactions. Applications
    can now control whether stack sends extra 100 Trying responses
    after N1 timer or retransmissions.
  + nta_leg_tag(leg, NULL) now always returns the tag (old or new).
  + SOA uses addresses present in SDP if they are local.
  + Deferrable timers were added.
  + Timing out forked INVITE client transactions is now done by
    stack.
  + An INVITE transaction that has been timed out with stack timer
    C is now CANCELed automatically. Previously, such INVITE client
    transactions were restarted instead of timing out under certain
    circumstances.
  + Added s2check library for writing check-based module tests for
    network protocols.
  + User Via header with NULL host and port gets filled
    automatically.
- Use source services: download_url, recompress, set_version.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files
* Wed Dec 24 2008 mboman@suse.de
- Update to version 1.12.10:
  + Numerous bugs has been fixed.
  + Some API additions/changes (API/ABI compatible)
* Thu Jul 31 2008 hfiguiere@suse.de
- Upgrade to 1.12.9
  * Better NAT traversal
  * Lot of bug fixes
  * Lot of small API additions (API/ABI compatible)
* Mon Jun  4 2007 mrueckert@suse.de
- added ldconfig call for the glib package and postun
- removed ldconfig call for devel package
- disable static libs
- move to the new library packaging policy
- *-utils package is now sofia-sip (provides for the old name is set)
* Sat May 12 2007 mrueckert@suse.de
- update to version 1.12.6
* Mon Apr  2 2007 mrueckert@suse.de
- update to version 1.12.5
* Sat Dec  2 2006 mrueckert@suse.de
- update to version 1.12.4
- build with -fno-strict-aliasing
- properly put the conditionals for glib2 on sles9
* Tue Oct  3 2006 mrueckert@suse.de
- update to version 1.12.3
* Sat Sep 30 2006 mrueckert@suse.de
- Initial package of version 1.12.2
